<?php
/**
 * Handles the Northmill Checkout payment gateways.
 *
 * @package flo-checkout
 */

namespace Flo_Checkout;

use Flo_Checkout\Gateways\Moreflo_Invoice_Pay;
use Flo_Checkout\Gateways\NMI_Pay;
use Flo_Checkout\Gateways\Resurs_Invoice_Pay;
use Flo_Checkout\Gateways\Swish_Pay;

/**
 * Gateways class.
 */
class Gateways {

	/**
	 * Setup all plugin gateways.
	 *
	 * @return void
	 */
	public static function setup(): void {
		if ( ! class_exists( 'WC_Payment_Gateway' ) ) {
			return;
		}

		$gateway_classes = array(
			Swish_Pay::class,
			Resurs_Invoice_Pay::class,
			NMI_Pay::class,
			Moreflo_Invoice_Pay::class,
		);

		$gateway_classes = apply_filters( 'flo_checkout_gateway_classes', $gateway_classes );

		foreach ( $gateway_classes as $gateway_class ) {
			self::setup_gateway( $gateway_class );
		}
	}

	/**
	 * Set up a gateway.
	 *
	 * @param string $gateway_class The gateway class.
	 *
	 * @return void
	 */
	private static function setup_gateway( string $gateway_class ): void {

		if ( ! is_a( $gateway_class, 'WC_Payment_Gateway', true ) ) {
			return;
		}

		if ( method_exists( $gateway_class, 'public_setup' ) ) {
			$gateway_class::public_setup();
		}

		add_filter(
			'woocommerce_payment_gateways',
			function ( $methods ) use ( $gateway_class ) {
				$methods[] = $gateway_class;
				return $methods;
			}
		);
	}
}
