<?php
/**
 * Credit Card Payments with Northmill
 *
 * @version     1.0.0
 *
 * @package flo-checkout
 */

namespace Flo_Checkout\Gateways\NMI;

class NMI_Hash_Input {
	public const ORDER_TYPE            = 'order_type';
	public const DATETIME_FORMAT       = 'h:i:sa';
	public const SUCCESS               = 'success';
	public const EKASHU_REFERENCE      = 'ekashu_reference';
	public const EKASHU_TRANSACTION_ID = 'ekashu_transaction_id';

	public static function validate_hash( $data, $endpoint ) {
		$post_data = null;

		if ( ! isset( $data['ekashu_hash_code'] ) ) {
			return false;
		}
		if ( ! isset( $data['ekashu_hash_code_format'] ) ) {
			return false;
		}
		if ( ! isset( $data['ekashu_hash_code_result'] ) ) {
			return false;
		}
		if ( ! isset( $data['ekashu_hash_code_result_format'] ) ) {
			return false;
		}
		if ( ! isset( $data['ekashu_hash_code_result_type'] ) ) {
			return false;
		}
		if ( ! isset( $data['ekashu_hash_code_result_version'] ) ) {
			return false;
		}
		if ( ! isset( $data['ekashu_hash_code_type'] ) ) {
			return false;
		}
		if ( ! isset( $data['ekashu_hash_code_version'] ) ) {
			return false;
		}

		foreach ( $data as $name => $value ) {
			if ( preg_match( '/ekashu_/', $name ) == 1 ) {
				$post_data .= urlencode( $name ) . '=' . urlencode( $value );
				$post_data .= '&';
			}
		}

		$post_data = substr( $post_data, 0, - 1 );

		$response = wp_remote_post(
			$endpoint . '/validate_hash_code.php',
			array(
				'body' => $post_data,
			)
		);

		return 200 == wp_remote_retrieve_response_code( $response );
	}

	public function __construct( $data = array() ) {
		$required_keys = array(
			'ekashu_amount',
			'ekashu_currency',
			'ekashu_reference',
			'ekashu_seller_id',
			'ekashu_seller_key',
		);
		if ( empty( $data ) || ! $this->array_has_all_keys( $required_keys, $data ) ) {
			throw new Exception( 'Bad Nmi hash generation', 1 );
		}

		foreach ( $data as $key => $value ) {
			$this->{$key} = $value;
		}
	}

	public function get_hash( $hash_key ) {
		$hash_code_input = (array) $this;
		ksort( $hash_code_input );

		$hash_code = null;
		foreach ( $hash_code_input as $name => $value ) {
			$hash_code .= trim( $value );
			$hash_code .= '&';
		}

		$hash_code = substr( $hash_code, 0, - 1 );

		return base64_encode( hash_hmac( 'sha256', $hash_code, $hash_key, true ) );
	}

	public function get_form_data() {
		$hash_code_input = (array) $this;
		ksort( $hash_code_input );

		return $hash_code_input;
	}

	public $ekashu_3d_secure_verify                 = null;
	public $ekashu_amount                           = null;
	public $ekashu_amount_format                    = null;
	public $ekashu_auto_confirm                     = null;
	public $ekashu_callback_failure_url             = null;
	public $ekashu_callback_include_post            = null;
	public $ekashu_callback_success_url             = null;
	public $ekashu_card_address_editable            = null;
	public $ekashu_card_address_required            = null;
	public $ekashu_card_address_verify              = null;
	public $ekashu_card_email_address_mandatory     = null;
	public $ekashu_card_phone_number_mandatory      = null;
	public $ekashu_card_title_mandatory             = null;
	public $ekashu_card_zip_code_verify             = null;
	public $ekashu_currency                         = null;
	public $ekashu_delivery_address_editable        = null;
	public $ekashu_delivery_address_required        = null;
	public $ekashu_delivery_email_address_mandatory = null;
	public $ekashu_delivery_phone_number_mandatory  = null;
	public $ekashu_delivery_title_mandatory         = null;
	public $ekashu_description                      = null;
	public $ekashu_device                           = null;
	public $ekashu_duplicate_check                  = null;
	public $ekashu_duplicate_minutes                = null;
	public $ekashu_failure_return_text              = null;
	public $ekashu_failure_url                      = null;
	public $ekashu_hash_code_format                 = null;
	public $ekashu_hash_code_type                   = 'SHA256HMAC';
	public $ekashu_hash_code_version                = '2.0.0';
	public $ekashu_include_post                     = null;
	public $ekashu_invoice_address_editable         = null;
	public $ekashu_invoice_address_required         = null;
	public $ekashu_invoice_email_address_mandatory  = null;
	public $ekashu_invoice_phone_number_mandatory   = null;
	public $ekashu_invoice_title_mandatory          = null;
	public $ekashu_locale                           = null;
	public $ekashu_payment_methods                  = null;
	public $ekashu_reference                        = null;
	public $ekashu_request_type                     = null;
	public $ekashu_return_text                      = null;
	public $ekashu_seller_address                   = null;
	public $ekashu_seller_email_address             = null;
	public $ekashu_seller_id                        = null;
	public $ekashu_seller_key                       = null;
	public $ekashu_seller_name                      = null;
	public $ekashu_shortcut_icon                    = null;
	public $ekashu_title                            = null;
	public $ekashu_style_sheet                      = null;
	public $ekashu_success_url                      = null;
	public $ekashu_verification_value_mask          = null;
	public $ekashu_verification_value_verify        = null;
	public $ekashu_viewport                         = null;

	private function array_has_all_keys( $keys, $arr ) {
		if ( empty( $keys ) ) {
			return true;
		}

		foreach ( $keys as $key ) {
			if ( ! isset( $arr[ $key ] ) ) {
				return false;
			}
		}

		return true;
	}
}
