<?php
/**
 * Handles plugin setup.
 */

namespace Flo_Checkout;

/**
 * Class for plugin setup.
 */
class Setup {

	/**
	 * Performs the necessary setup tasks for the plugin.
	 *
	 * @return void
	 */
	public static function setup(): void {
		i18n::load_txt_domain();

		if ( ! class_exists( '\WooCommerce' ) ) {
			add_action( 'admin_notices', array( self::class, 'display_woocommerce_not_enabled_notice' ) );
			return;
		}

		if ( is_admin() ) {
			new Plugin_Update();
		}

		Gateways::setup();
	}

	/**
	 * Displays an error notice if the WooCommerce plugin is not enabled.
	 */
	public static function display_woocommerce_not_enabled_notice(): void {
		echo '<div class="error"><p><strong>';

		printf(
		// Translators: %s is a link to the WooCommerce plugin.
			esc_html__(
				'Northmill Checkout requires WooCommerce to be installed and active. You can download %s here.',
				'flo-sync'
			),
			'<a href="https://woocommerce.com/" target="_blank">WooCommerce</a>'
		);

		echo '</strong></p></div>';
	}
}
